==> haskell-wai-cors-0.2.6-26-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-cors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-cors
version: 0.2.6
id: wai-cors-0.2.6-KZ9t7By8eYs6k2hQo5pw1
key: wai-cors-0.2.6-KZ9t7By8eYs6k2hQo5pw1
license: MIT
copyright: (c) 2015-2017 Lars Kuhtz <lakuhtz@gmail.com>,
           (c) 2014 AlephCloud Systems, Inc.
maintainer: Lars Kuhtz <lakuhtz@gmail.com>
homepage: https://github.com/larskuhtz/wai-cors
synopsis: CORS for WAI
description:
    This package provides an implemenation of
    Cross-Origin resource sharing (CORS) for
    <http://hackage.haskell.org/package/wai Wai>
    that aims to be compliant with <http://www.w3.org/TR/cors>.
category: HTTP, Network, Web, Yesod
author: Lars Kuhtz <lakuhtz@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Network.Wai.Middleware.Cors
abi: 426f7d14dc688c1fe6378b62fc6f6c58
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/wai-cors-0.2.6
library-dirs: /usr/lib/ghc-8.2.2/site-local/wai-cors-0.2.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/wai-cors-0.2.6
hs-libraries: HSwai-cors-0.2.6-KZ9t7By8eYs6k2hQo5pw1
depends:
    attoparsec-0.13.2.2-1iFrnKzrZDOGKCpRsHPeZj base-4.10.1.0
    base-unicode-symbols-0.2.2.4-5S5alRFlq9h8rWVSfYKtGd
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-6XUs0OYFV3wE0SFwF3qQ2a
    http-types-0.9.1-6X2WIr2ON586RGGZSRTan8
    wai-3.2.1.2-DsLSlUMPljoENiFUuH3YiB mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    transformers-0.5.2.0
abi-depends: attoparsec-0.13.2.2-1iFrnKzrZDOGKCpRsHPeZj=9d8982f8b70cf41a2e1b007eb9382565
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             base-unicode-symbols-0.2.2.4-5S5alRFlq9h8rWVSfYKtGd=86cdfd320381e3b6402e7ebee3130f87
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             case-insensitive-1.2.0.11-6XUs0OYFV3wE0SFwF3qQ2a=d08ac5e9b3f9d5ae0bee3532b0fd2d5e
             http-types-0.9.1-6X2WIr2ON586RGGZSRTan8=f3cf44f811b734b379910c70c68230da
             wai-3.2.1.2-DsLSlUMPljoENiFUuH3YiB=591867d961152e6769889f7aae419d50
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=ada793ec1f149425d0c0689d53e1173b
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
haddock-interfaces: /usr/share/doc/haskell-wai-cors/html/wai-cors.haddock
haddock-html: /usr/share/doc/haskell-wai-cors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-cors-0.2.6-28-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-cors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-cors
version: 0.2.6
id: wai-cors-0.2.6-EJ1P4Fx8ErxPoHX0Yu6Wl
key: wai-cors-0.2.6-EJ1P4Fx8ErxPoHX0Yu6Wl
license: MIT
copyright: (c) 2015-2017 Lars Kuhtz <lakuhtz@gmail.com>,
           (c) 2014 AlephCloud Systems, Inc.
maintainer: Lars Kuhtz <lakuhtz@gmail.com>
homepage: https://github.com/larskuhtz/wai-cors
synopsis: CORS for WAI
description:
    This package provides an implemenation of
    Cross-Origin resource sharing (CORS) for
    <http://hackage.haskell.org/package/wai Wai>
    that aims to be compliant with <http://www.w3.org/TR/cors>.
category: HTTP, Network, Web, Yesod
author: Lars Kuhtz <lakuhtz@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Network.Wai.Middleware.Cors
abi: 741dc72483a5a9ea66c0631950d1b676
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/wai-cors-0.2.6
library-dirs: /usr/lib/ghc-8.2.2/site-local/wai-cors-0.2.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/wai-cors-0.2.6
hs-libraries: HSwai-cors-0.2.6-EJ1P4Fx8ErxPoHX0Yu6Wl
depends:
    attoparsec-0.13.2.2-9YjPD6eySTr2XtEq1V3i2t base-4.10.1.0
    base-unicode-symbols-0.2.2.4-5S5alRFlq9h8rWVSfYKtGd
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-6XUs0OYFV3wE0SFwF3qQ2a
    http-types-0.9.1-6X2WIr2ON586RGGZSRTan8
    wai-3.2.1.2-DsLSlUMPljoENiFUuH3YiB mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    transformers-0.5.2.0
abi-depends: attoparsec-0.13.2.2-9YjPD6eySTr2XtEq1V3i2t=e275f62d517bb5373c55830561137640
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             base-unicode-symbols-0.2.2.4-5S5alRFlq9h8rWVSfYKtGd=86cdfd320381e3b6402e7ebee3130f87
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             case-insensitive-1.2.0.11-6XUs0OYFV3wE0SFwF3qQ2a=d08ac5e9b3f9d5ae0bee3532b0fd2d5e
             http-types-0.9.1-6X2WIr2ON586RGGZSRTan8=f3cf44f811b734b379910c70c68230da
             wai-3.2.1.2-DsLSlUMPljoENiFUuH3YiB=591867d961152e6769889f7aae419d50
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=ada793ec1f149425d0c0689d53e1173b
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
haddock-interfaces: /usr/share/doc/haskell-wai-cors/html/wai-cors.haddock
haddock-html: /usr/share/doc/haskell-wai-cors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
